Learn R Programming

pwr2ppl (version 0.2.0)

modmed15: Compute Power for Conditional Process Model 15 Joint Significance Requires correlations between all variables as sample size. This is the recommended approach for determining power

Description

Compute Power for Conditional Process Model 15 Joint Significance Requires correlations between all variables as sample size. This is the recommended approach for determining power

Usage

modmed15(
  rxw,
  rxm,
  rxmw,
  rxy,
  rwm = 0,
  rmww,
  rwxw,
  rwy,
  rmwm = 0,
  rmxw,
  rmwy,
  rxwy,
  rxwmw,
  rmy,
  rxwx,
  rmwxw,
  n,
  alpha = 0.05,
  rep = 5000
)

Arguments

rxw

Correlation between predictor (x) and moderator (w)

rxm

Correlation between predictor (x) and mediator (m)

rxmw

Correlation between predictor (x) and interaction (mw) - Key value

rxy

Correlation between DV (y) and predictor (x)

rwm

Correlation between moderator (w) and mediator (m)

rmww

Correlation between mediator (m) and interaction (mw) - defaults to 0

rwxw

Correlation between moderator (w) and interaction (xw) - Key value

rwy

Correlation between DV (y) and moderator (w)

rmwm

Correlation between mediator (m) and interaction (xmw) - Key value

rmxw

Correlation between mediator (m) and interaction (xw) - defaults to 0

rmwy

Correlation between dv (y) and interaction (mw) - Key value

rxwy

Correlation between DV (y) and interaction (xw) - defaults to 0

rxwmw

Correlation between interaction (mw) and interaction (mw) - Key value

rmy

Correlation between DV (y) and mediator (m)

rxwx

Correlation between moderator (w) and interaction (xw) - defaults to 0

rmwxw

Correlation between inteaction (xw) and interaction (mw) - Key value

n

Sample size

alpha

Type I error (default is .05)

rep

Number of samples drawn (defaults to 5000)

Value

Power for Model 15 Conditional Processes

Examples

Run this code
# NOT RUN {
modmed15(rxw=.40, rxm=.42, rxy=.5, rwm=.45, rmxw=.0,rmww=.01, rwy=.2,
rmwm=.46,rwxw=.21,rxwy=.31,rmy=.30,rxwx=.1, rmwy=.02,rxmw=.21,rmwxw=.22,rep=5000, alpha=.05, n=400)
# }

Run the code above in your browser using DataLab