Learn R Programming

pwr2ppl (version 0.2.0)

modmed7: Compute Power for Model 7 Conditional Processes Using Joint Significance Requires correlations between all variables as sample size. This is the recommended approach for determining power

Description

Compute Power for Model 7 Conditional Processes Using Joint Significance Requires correlations between all variables as sample size. This is the recommended approach for determining power

Usage

modmed7(
  rxm,
  rxw,
  rxxw,
  rxy,
  rwm,
  rwxw,
  rwy = 0,
  rmxw,
  rmy,
  rxwy = 0,
  alpha = 0.05,
  rep = 1000,
  n = NULL
)

Arguments

rxm

Correlation between predictor (x) and mediator (m)

rxw

Correlation between predictor (x) and moderator (w)

rxxw

Correlation between predictor (x) and interaction term (xw) - defaults to 0

rxy

Correlation between DV (y) and predictor (x)

rwm

Correlation between moderator (w) and mediator (m)

rwxw

Correlation between moderator (w) and interaction (xw) - defaults to 0

rwy

Correlation between DV (y) and moderator (w)

rmxw

Correlation between mediator (m) and interaction (xw) - Key value

rmy

Correlation between DV (y) and mediator (m)

rxwy

Correlation between DV (y) and interaction (xw) - defaults to 0

alpha

Type I error (default is .05)

rep

Number of samples drawn (defaults to 5000)

n

Sample size

Value

Power for Model 7 Conditional Processes

Examples

Run this code
# NOT RUN {
modmed7(rxm=.4, rxw=.3, rxxw=.01, rxy=.50, rmy=.31, rxwy=.02,rwm=.45,
rwy=.2,rmxw = .24, rwxw=.21, alpha=.05,rep=1000,n=400)
# }

Run the code above in your browser using DataLab