Learn R Programming

pwr2ppl (version 0.2.0)

modmed8: Compute Power for Power for Model 8 Conditional Processes Using Joint Significance Requires correlations between all variables as sample size. This is the recommended approach for determining power

Description

Compute Power for Power for Model 8 Conditional Processes Using Joint Significance Requires correlations between all variables as sample size. This is the recommended approach for determining power

Usage

modmed8(
  rxw,
  rxm,
  rxxw,
  rxy,
  rwm = 0,
  rwy,
  rxwm,
  rxwy,
  rwxw,
  rmy,
  n,
  alpha = 0.05,
  rep = 5000
)

Arguments

rxw

Correlation between predictor (x) and moderator (w)

rxm

Correlation between predictor (x) and mediator (m)

rxxw

Correlation between predictor (x) and interaction term (xw) - defaults to 0

rxy

Correlation between DV (y) and predictor (x)

rwm

Correlation between moderator (w) and mediator (m)

rwy

Correlation between DV (y) and moderator (w)

rxwm

Correlation between mediator (m) and interaction (xw) - Key value

rxwy

Correlation between DV (y) and interaction (xw) - defaults to 0

rwxw

Correlation between moderator (w) and interaction (xw) - defaults to 0

rmy

Correlation between DV (y) and mediator (m)

n

Sample size

alpha

Type I error (default is .05)

rep

Number of samples drawn (defaults to 5000)

Value

Power for Model 8 Conditional Processes

Examples

Run this code
# NOT RUN {
modmed8(rxw<-.21, rxm<-.31, rxxw=0, rxy=.32,rwm=.40,
rmy=.19,rwy=.22,rwxw=.23,rxwm=.24,rxwy=.18,alpha=.05,rep=1000,n=400)
# }

Run the code above in your browser using DataLab